@@ -1,9 +1,10 @@
 
-#' Factory for configuring a gene dependent DecodeGene function.
+#' Factory for configuring a gene-dependent DecodeGene function.
 #'
-#' @description A gene specific decoder must be provided.
+#' @description A gene-specific decoder must be provided.
 #'
-#' @param algorithm  "sga", "sgde", "sgperm", "sge", sgp". Default: "sga".
+#' @param algorithm  "sga", "sgde", "sgperm", "sge", "sgede", 
+#'                   "sgp". Default: "sga".
 #'
 #' @param method     Method. Default: "DecodeGene". 
 #'
@@ -16,7 +17,7 @@
 #'
 #'@importFrom xegaGaGene xegaGaDecodeGene
 #'@importFrom xegaGpGene xegaGpDecodeGene
-#'@importFrom xegaGeGene xegaGeDecodeGene
+#'@importFrom xegaGeGene xegaGeDecodeGeneFactory
 #'@importFrom xegaDfGene xegaDfDecodeGene
 #'@importFrom xegaPermGene xegaPermDecodeGene
 #'@export
@@ -24,7 +25,8 @@ sgXDecodeGeneFactory<-function(algorithm="sga", method="DecodeGene")
 {
    if (algorithm=="sga") {f<-xegaGaGene::xegaGaDecodeGene}
    if (algorithm=="sgp") {f<-xegaGpGene::xegaGpDecodeGene}
-   if (algorithm=="sge") {f<-xegaGeGene::xegaGeDecodeGene}
+   if (algorithm=="sge") {f<-xegaGeGene::xegaGeDecodeGeneFactory(method)}
+   if (algorithm=="sgede") {f<-xegaGeGene::xegaGeDecodeGeneFactory(method)}
    if (algorithm=="sgde") {f<-xegaDfGene::xegaDfDecodeGene}
    if (algorithm=="sgperm") {f<-xegaPermGene::xegaPermDecodeGene}
 if (!exists("f", inherits=FALSE))
